@@ -69,7 +69,7 @@ class Imdb:
         imdb_id = self.validate_id(imdb_id)
         url = self.build_url('/title/fullcredits', {'tconst': imdb_id})
         result = self.get(url)
-        return result["data"]["credits"]
+        return result.get('data').get('credits')
 
     def filter_out(self, string):
         return string not in ('id', 'title')
